onedata-lambda-utils
========================
Python Library containing utility functions for use in OpenFaaS lambda implementations

## Installation

Installation:
```bash
   python -m pip install onedata_lambda_utils
```
